@@ -31,7 +31,7 @@ I therefore include their BSD statement here.
     For portions of this code, copyright and license information differs from
     the above. In these cases, copyright and/or license information is inline.
 
-In turn some of the code in this file was derived from the Python package 
+In turn some of the code in this file was derived from the Python package
 pfile-tools project, https://github.com/njvack/pfile-tools
 and as such we have included their BSD statement in this file.
 
@@ -46,7 +46,7 @@ and as such we have included their BSD statement in this file.
         * Redistributions in binary form must reproduce the above copyright notice, this
           list of conditions and the following disclaimer in the documentation and/or
           other materials provided with the distribution.
-        * Neither the name of the University of Wisconsin nor the names of its 
+        * Neither the name of the University of Wisconsin nor the names of its
           contributors may be used to endorse or promote products derived from this
           software without specific prior written permission.
 
@@ -104,8 +104,8 @@ class RevisionNumBig(ct.BigEndianStructure):
 
 class Pfile:
     """
-    This class was based on the style of code from the pfile-tools 
-    package written by Nathan Vack in that we use ctypes to organize 
+    This class was based on the style of code from the pfile-tools
+    package written by Nathan Vack in that we use ctypes to organize
     the reading of binary structures into a Python readable class
     instance. We have also incorporated code from their struct
     utilities modules as part of our class in order to dump out the
@@ -114,24 +114,24 @@ class Pfile:
     We use a subset of header variables that are sufficient to read the
     data from P-files in which we are interested. The structure for these
     variables was adapted from similar code found in the UCSF Sivic project.
-    
+
 
     """
     def __init__(self, fname):
-    
+
         self.file_name  = fname
         self.version    = 0
         self.hdr        = None
         self.map        = None
         self.endian     = 'little'  # def for version >= 11
-        
+
         self.read_header()
-        
+
         if not self.is_ge_file:
             raise UnknownPfile("Not a known GE Pfile - fname = %s" % fname)
-        
+
         self.map_data()
-        
+
     # Properties --------------------------------------------------
 
     @property
@@ -147,7 +147,7 @@ class Pfile:
             # may well be redundant anyway, since revision number has
             # previously been validated in _version
             if offset in \
-                    [
+                    (
                         61464,   # bjs from Matlab script for ver = 9
                         66072,
                         145908,
@@ -157,30 +157,30 @@ class Pfile:
                         213684,  # 26.002
                         219828,  # 27.000
                         228020   # 28.003
-                    ]:
+                    ):
                 return True
             else:
                 return False
 
     @property
     def is_svs(self):
-        
-        if self.map is None: 
+
+        if self.map is None:
             return False
         else:
-            return self.map.is_svs     
+            return self.map.is_svs
 
     @property
     def get_mapper(self):
-        
-        if self.hdr is None: 
+
+        if self.hdr is None:
             return None
-            
+
         psd = self.hdr.rhi_psdname.decode('utf-8').lower()
-        
+
         if psd == 'probe-p':
             mapper = PfileMapper
-        elif psd in ['oslaser', 'slaser_cni']:
+        elif psd in ('oslaser', 'slaser_cni'):
             mapper = PfileMapperSlaser
         elif psd == 'presscsi':
             mapper = PfileMapper
@@ -207,7 +207,7 @@ class Pfile:
             mapper = PfileMapperGaba
         else:
             raise UnknownPfile("No Pfile mapper for pulse sequence = %s" % psd)
-        
+
         return mapper
 
     def read_header(self):
@@ -217,29 +217,29 @@ class Pfile:
         # determine version number of this header from revision of rdbm.h
         version = self._version(filelike)
         if version == 0:
-            raise UnknownPfile("Pfile not supported for version %s" % version)    
-  
+            raise UnknownPfile("Pfile not supported for version %s" % version)
+
         # Here we dynamically configure the ctypes structures into which the
         # binary file will be read, based on the revision number
         #
         # Note. Determined empirically that I cannot declare the XxxHeader
-        # class at the top level of the module with an attribute ._fields_ = [] 
-        # and then append into it. I have to create a list and then assign 
+        # class at the top level of the module with an attribute ._fields_ = []
+        # and then append into it. I have to create a list and then assign
         # _fields_ attribute to that list in one step.  Don't know why.
         #
         # Note 2. Had to move Class definition into this function so that the
         # class can be reconstituted more than once for multiple GE file reads.
-        # At the top level of the module, the _fields_ attribute could be 
+        # At the top level of the module, the _fields_ attribute could be
         # created once dynamically, but afterwards would stick around and
-        # could not then be changed. 
-        
+        # could not then be changed.
+
         if self.endian == 'big':
             class PfileHeaderBig(ct.BigEndianStructure):
                 """
                 Contains the ctypes Structure for a GE P-file rdb header.
                 Dynamically allocate the ctypes _fields_ list later depending on revision
                 """
-                _pack_   = 1            
+                _pack_   = 1
                 _fields_ = get_pfile_hdr_fields(version)
                 # _fields_ = utilge.get_pfile_hdr_fields(version)
             hdr = PfileHeaderBig()
@@ -253,7 +253,7 @@ class Pfile:
                 _fields_ = get_pfile_hdr_fields(version)
                 # _fields_ = utilge.get_pfile_hdr_fields(version)
             hdr = PfileHeaderLittle()
-  
+
         try:
             # read  header information from start of file
             filelike.seek(0)
@@ -262,7 +262,7 @@ class Pfile:
         except Exception:
             filelike.close()
             raise UnknownPfile("Trouble reading file into header structure for version %s" % version)
-        
+
         self.version = version
         self.hdr = hdr
 
@@ -270,7 +270,7 @@ class Pfile:
         """
         Select appropriate mapper class using the pulse sequence name string,
         instantiate and read the data from the file into the 'map' attribute
-        
+
         """
         mapper = self.get_mapper
         self.map = mapper(self.file_name, self.hdr, self.version, self.endian)
@@ -309,7 +309,7 @@ class Pfile:
                 25.001, 25.002, 25.003, 25.004,
                 26.000, 26.001, 26.002,
                 27.000, 27.001,
-                28.000, 28.002, 28.003 
+                28.000, 28.002, 28.003
             ]
 
         # Note that caution is needed for float comparisons, given the
@@ -352,7 +352,7 @@ class Pfile:
             if (info.label.find("pad") == 0):
                 continue
             # needed this because Gregor's UID values had some odd chars which
-            # caused errors on the import of Probep data 
+            # caused errors on the import of Probep data
             try:
                 val = info.value
                 # needed this because Pom's UID values were causing errors
@@ -369,9 +369,9 @@ class Pfile:
             except Exception:
                 val = ' '
             strarr.append(str(info.label) + '        ' + val)
-            
+
         return strarr
-        
+
     def dump_header(self):
 
         dumped = self._dump_struct(self.hdr)
@@ -392,31 +392,31 @@ class Pfile:
         output = []
         self._dump_struct_rec(struct, output, include_structs)
         return output
-    
+
     def _dump_struct_rec(self, struct, output, include_structs=False, prefix='', depth=0, base_offset=0):
         """
         Internal recursive method for dumping structures.
         Appends to the "output" parameter.
-        
+
         """
         struct_class = type(struct)
         if include_structs:
             output.append(StructInfo(
-                "%s (%s)" % (prefix, struct_class.__name__),
+                f"{prefix} ({struct_class.__name__})",
                 depth, '', str(struct_class), ctypes.sizeof(struct_class), base_offset))
         for f in struct._fields_:
             name = f[0]
             field_type = f[1]
             field_meta = getattr(struct_class, name)
             field = getattr(struct, name)
-            cur_prefix = "%s%s." % (prefix, name)
+            cur_prefix = f"{prefix}{name}."
             field_offset = base_offset + field_meta.offset
             if isinstance(field, ctypes.Structure):
                 self._dump_struct_rec(field, output, include_structs, cur_prefix, depth + 1, field_offset)
             else:
                 label = prefix + name
                 output.append(StructInfo(label, depth, field, field_type.__name__, field_meta.size, field_offset))
-    
+
 
 # ------------------------------------------------------------------------------
 # originally ge_pfile_mapper.py
@@ -429,37 +429,37 @@ class PfileMapper:
         """
         Given a file name, its header, version number and endianness, this
         class will parse the data section of the file for the suppressed and
-        unsuppressed data.  
-        
-        All 'timePts' (aka. FID data arrays) are stored in the raw_data 
+        unsuppressed data.
+
+        All 'timePts' (aka. FID data arrays) are stored in the raw_data
         attribute. It is a numpy ndarray with shape of:
-        
+
         [cols, rows, slices, numTimePts, numCoils, numSpecPts], np.complex64
-        
-        For SVS data, cols, rows and slices are all equal to 1. 
-        
+
+        For SVS data, cols, rows and slices are all equal to 1.
+
             - raw_suppressed   is a view onto the  water suppressed fids data
             - raw_unsuppressed is a view onto the water unsuppressed fids data
             - avg_suppressed and avg_unsuppressed are numpy arrays where the
                   relevant raw_ views have been summed along the numTimePts
                   dimension. shape = [cols, rows, slices, numCoils, numSpecPts]
-                  
+
         For non-SVS data, only the raw_data attribute has data in it.
-        
+
         History:
-        
+
         Derived from SIVIC file svkGEPFileMapper.cc which was used to map data
         from PROBE-P and PRESSCSI P-files.  SIVIC has other mapper classes for
         other types of P-file data. I will plan on using this model here, too.
-        
+
         """
-        
+
         self.file_name = file_name
         self.hdr       = hdr
         self.version   = version
         self.endian    = endian
         self.is_svs    = False
-        
+
         self.raw_data         = None
         self.raw_suppressed   = None
         self.avg_suppressed   = None
@@ -474,20 +474,20 @@ class PfileMapper:
         but with the LX architecture, this held the table position only,
         so if Graphic RX was used to introduce an offset, it wouldn't
         be successfully extracted.
-        
+
         """
         center0 = self.hdr.rhi_user11
         center1 = self.hdr.rhi_user12
         center2 = self.hdr.rhi_user13
-        
+
         return np.array([center0, center1, center2])
 
     @property
-    def get_select_box_size(self):        
-        
+    def get_select_box_size(self):
+
         boxsize = np.array([0.0, 0.0, 0.0])
         dcos = self.get_dcos
-        
+
         if self.version > 9:
 
             lMax   = 0
@@ -502,7 +502,7 @@ class PfileMapper:
                     lMax = abs(dcos[i][0])
                 if abs(dcos[i][1]) > pMax:
                     pIndex = i
-                    pMax = abs(dcos[i][1]) 
+                    pMax = abs(dcos[i][1])
                 if abs(dcos[i][2]) > sMax:
                     sIndex = i
                     sMax = abs(dcos[i][2])
@@ -521,11 +521,11 @@ class PfileMapper:
                 ftemp = boxsize[0]
                 boxsize[0] = boxsize[1]
                 boxsize[1] = ftemp
-        
+
         return boxsize
 
     @property
-    def get_voxel_spacing(self):  
+    def get_voxel_spacing(self):
         """
         Get the voxel spacing in 3D. Note that the slice spacing may include
         a skip.
@@ -534,7 +534,7 @@ class PfileMapper:
         """
         user19 = self.hdr.rhi_user19
         voxspace = np.array([0.0, 0.0, 0.0])
-        
+
         if (user19 > 0) and (self.version > 9):
             voxspace[0] = user19
             voxspace[1] = user19
@@ -544,17 +544,17 @@ class PfileMapper:
             nvox = self.get_num_voxels
             voxspace[0] = fov[0] / nvox[0]
             voxspace[1] = fov[1] / nvox[1]
-            voxspace[2] = fov[2] / nvox[2]       
-    
+            voxspace[2] = fov[2] / nvox[2]
+
         return voxspace
 
     @property
-    def get_fov(self): 
+    def get_fov(self):
         fov  = np.array([0.0, 0.0, 0.0])
         nvox = self.get_num_voxels
-    
+
         dfov = self.hdr.rhi_dfov
-        
+
         if self.version > 9:
 
             fov[0] = dfov
@@ -573,7 +573,7 @@ class PfileMapper:
         #  Anisotropic voxels:
         if (self.version > 9) and (nvox[0] != nvox[1]):
 
-            # CSI has already been reordered if needed - so fov  calculated 
+            # CSI has already been reordered if needed - so fov  calculated
             # with this CSI will not need reordering, need next power of 2:
             xdim = int(pow(2, math.ceil(math.log(nvox[0], 2))))
             ydim = int(pow(2, math.ceil(math.log(nvox[1], 2))))
@@ -593,18 +593,18 @@ class PfileMapper:
             fov[0] = fov[1]
             fov[1] = temp
 
-        return fov        
+        return fov
 
     @property
-    def get_num_voxels(self):   
+    def get_num_voxels(self):
         """
         Get the 3D spatial dimensionality of the data set
         Returns an int array with 3 dimensions.  Swaps
         if necessary based on freq_dir setting.
-        
+
         """
         nvox = np.array([0, 0, 0])
-     
+
         if self.hdr.rhr_rh_file_contents == 0:
             nvox[0] = 1
             nvox[1] = 1
@@ -623,13 +623,13 @@ class PfileMapper:
         return nvox
 
     @property
-    def get_dcos(self):      
-        dcos = np.zeros([3, 3], float)     
-     
+    def get_dcos(self):
+        dcos = np.zeros([3, 3], float)
+
         dcos[0][0] = (self.hdr.rhi_trhc_R - self.hdr.rhi_tlhc_R)
         dcos[0][1] = (self.hdr.rhi_trhc_A - self.hdr.rhi_tlhc_A)
         dcos[0][2] =  (self.hdr.rhi_trhc_S - self.hdr.rhi_tlhc_S)
-        
+
         dcosLengthX = np.sqrt(dcos[0][0] * dcos[0][0]
                               + dcos[0][1] * dcos[0][1]
                               + dcos[0][2] * dcos[0][2])
@@ -660,16 +660,16 @@ class PfileMapper:
         return dcos
 
     @property
-    def is_swap_on(self):      
-        """ Is frequency direction swapped? """     
+    def is_swap_on(self):
+        """ Is frequency direction swapped? """
         if self.hdr.rhi_freq_dir != 1:
             return True
         else:
             return False
 
     @property
-    def is_2d(self):      
-        """ Is this a 2D or 3D data set (spatial dimensions)? """        
+    def is_2d(self):
+        """ Is this a 2D or 3D data set (spatial dimensions)? """
         is2D = False
         ndims = self.hdr.rhr_csi_dims
 
@@ -687,8 +687,8 @@ class PfileMapper:
         return is2D
 
     @property
-    def is_chop_on(self):      
-        """ Is data chopped? """        
+    def is_chop_on(self):
+        """ Is data chopped? """
         chop  = False
         nex   = self.hdr.rhi_nex
         necho = self.hdr.rhi_numecho
@@ -699,18 +699,18 @@ class PfileMapper:
         return chop
 
     @property
-    def get_frequency_offset(self):      
-        """ Returns the spectral frquency offset """        
+    def get_frequency_offset(self):
+        """ Returns the spectral frquency offset """
         if self.version > 9:
             return 0.0
         else:
             return self.hdr.rhr_rh_user13
 
     @property
-    def get_center_from_raw_file(self):      
-        """ 
+    def get_center_from_raw_file(self):
+        """
         Gets the center of the acquisition grid.  May vary between sequences.
-        
+
         """
         center = np.array([0.0, 0.0, 0.0])
         if self.version < 11:
@@ -721,11 +721,11 @@ class PfileMapper:
             center[0] = -1 * self.hdr.rhi_user11
             center[1] = -1 * self.hdr.rhi_user12
             center[2] = self.hdr.rhi_user13
-       
+
         return center
 
     @property
-    def get_num_coils(self):      
+    def get_num_coils(self):
         """ Determine number of coils of data in the PFile. """
         ncoils = 0
         for i in range(4):
@@ -739,11 +739,11 @@ class PfileMapper:
         if ncoils == 0:
             ncoils = 1
 
-        return int(ncoils)   
+        return int(ncoils)
 
     @property
-    def get_num_time_points(self):      
-        """ 
+    def get_num_time_points(self):
+        """
         Determine number of time points in the PFile.
         Number of time points is determined from the file size,
         number of voxels and number of coils.
@@ -764,17 +764,17 @@ class PfileMapper:
         return int(numTimePoints)
 
     @property
-    def get_num_dummy_scans(self):        
+    def get_num_dummy_scans(self):
         """
         Determine number of dummy scans (FIDs) in the data block.
         This is the difference between the raw pass size and the
         expected size of the data based on numCoils, numTimePts, numKSpacePts
-        and numFreqPts.        
-        
+        and numFreqPts.
+
         """
         passSize         = self.hdr.rhr_rh_raw_pass_size
-        numCoils         = self.get_num_coils 
-        numTimePoints    = self.get_num_time_points 
+        numCoils         = self.get_num_coils
+        numTimePoints    = self.get_num_time_points
         numSampledVoxels = self.get_num_kspace_points
         numFreqPoints    = self.hdr.rhr_rh_frame_size
         dataWordSize     = self.hdr.rhr_rh_point_size
@@ -787,7 +787,7 @@ class PfileMapper:
 
         #  Calc the diff between the size of the data buffer and the number of real data points
         #  then divide by the number of bytes in a single fid to get the number of dummy FIDs
-        numDummyScans = passSize - (numCoils * numTimePoints * numSampledVoxels 
+        numDummyScans = passSize - (numCoils * numTimePoints * numSampledVoxels
                                     * numFreqPoints * numComponents * dataWordSize)
 
         numDummyScans = numDummyScans / (numFreqPoints * numComponents * dataWordSize)
@@ -795,23 +795,23 @@ class PfileMapper:
         return int(numDummyScans)
 
     @property
-    def get_num_frames(self):    
-        """ Number of frames is number of slices * numCoils * numTimePoints """   
+    def get_num_frames(self):
+        """ Number of frames is number of slices * numCoils * numTimePoints """
 
         nvox = self.get_num_voxels
         nframes = nvox[2] * self.get_num_coils * self.get_num_time_points
 
         return int(nframes)
-   
+
     @property
-    def get_num_voxels_in_vol(self):    
+    def get_num_voxels_in_vol(self):
 
         nvox = self.get_num_voxels
-        
-        return int(nvox[0] * nvox[1] * nvox[2])   
+
+        return int(nvox[0] * nvox[1] * nvox[2])
 
     @property
-    def get_num_kspace_points(self):    
+    def get_num_kspace_points(self):
         """
         Determine the number of sampled k-space points in the data set.
         This may differ from the number of voxels in the rectalinear grid,
@@ -819,13 +819,13 @@ class PfileMapper:
         sampling strategy was employed.  GE product sequences pad the
         reduced k-space data with zeros so the number of k-space points
         is the same as the number of voxels, but that may not be true for
-        custom sequences.        
-        
+        custom sequences.
+
         """
         return int(self.get_num_voxels_in_vol)
 
     @property
-    def was_index_sampled(self):    
+    def was_index_sampled(self):
         """
         Determines whether a voxel (index) was sampled (or a zero padded
         point is present in the data set), or not, i.e. was it within
@@ -833,42 +833,42 @@ class PfileMapper:
         was used. Could be extended to support other sparse sampling
         trajectories. Note that for product sequences this always returns true
         since GE  zero-pads reduced k-space data to a full rectilinear grid.
-        
+
         """
-        return True   
+        return True
 
     @property
-    def get_number_unsuppressed_acquisitions(self):    
+    def get_number_unsuppressed_acquisitions(self):
         """
         For single voxel acquisitions, return the number of
-        unsuppressed acquisitions.        
-        
+        unsuppressed acquisitions.
+
         """
         nex = self.hdr.rhi_nex
         return int(16 / nex)
 
     @property
-    def get_number_suppressed_acquisitions(self):    
+    def get_number_suppressed_acquisitions(self):
         """
         For single voxel acquisitions, return the number of
-        suppressed acquisitions.        
-        
+        suppressed acquisitions.
+
         """
         nex   = self.hdr.rhi_nex
         user4 = self.hdr.rhi_user4
         return int(user4 / nex)
 
-    def add_dummy(self, offset, coilNum, timePt):      
-        """ 
+    def add_dummy(self, offset, coilNum, timePt):
+        """
         Determine whether to add a dummy scan. The assumption is that
         the number of dummy scans should be equal to the number of coils
         or numCoils * numTimePts (e.g. for a spectral editing sequence).
         If true, then the an FID worth of data should be skipped over when
-        reading data (e.g. frame_size * numComponents, or numFreqPts * numComponents)        
+        reading data (e.g. frame_size * numComponents, or numFreqPts * numComponents)
         """
         numDummyScans    = self.get_num_dummy_scans
         numCoils         = self.get_num_coils
-        numTimePoints    = self.get_num_time_points 
+        numTimePoints    = self.get_num_time_points
         numSampledVoxels = self.get_num_kspace_points
         numFreqPoints    = self.hdr.rhr_rh_frame_size
         numComponents    = 2
@@ -876,21 +876,21 @@ class PfileMapper:
 
         #  subtract the number of dummy words from the current offset to see if another
         #  dummy scan should be skipped or not
-        
+
         if numDummyScans == numCoils:
             numWordsBetweenDummies = numSampledVoxels * numPointsPerFID * numTimePoints
             offset = offset - (coilNum * numPointsPerFID)
             # additional time points have an offset that includes the per-coil dummy
             if timePt > 1:
                 offset = offset - numPointsPerFID
-        
+
         elif (numDummyScans == (numCoils * numTimePoints)):
             numWordsBetweenDummies = numSampledVoxels * numPointsPerFID
             offset = offset - (coilNum * numPointsPerFID) - ((coilNum + timePt) * numPointsPerFID)
-        
+
         elif numDummyScans == 0:    # bjs - added for fidcsi 13C data from Pom
             return False
-        
+
         else:
             numWordsBetweenDummies = None
             # "ERROR: Can not determine placement of dummy scans in raw file reader. \n"
@@ -901,13 +901,13 @@ class PfileMapper:
 
         return addDummy
 
-    def get_xyz_indices(self, dataIndex): 
+    def get_xyz_indices(self, dataIndex):
         """
         If swapping is turned on, the data will need to get mapped correctly
         from the input data buffer read from disk (specData) to the correct
         svkImageData arrays. If swap is true, then the data indices are swapped
         and ky is flipped.
-        
+
         """
 
         numVoxels = self.get_num_voxels
@@ -929,10 +929,10 @@ class PfileMapper:
         return x, y, z
 
     @staticmethod
-    def get_center_from_origin(origin, numVoxels, voxelSpacing, dcos): 
+    def get_center_from_origin(origin, numVoxels, voxelSpacing, dcos):
         """
         Calculates the LPS center from the origin(toplc).
-        
+
         """
         center = np.array([0.0, 0.0, 0.0])
 
@@ -943,10 +943,10 @@ class PfileMapper:
         return center
 
     @staticmethod
-    def get_origin_from_center(center, numVoxels, voxelSpacing, dcos): 
+    def get_origin_from_center(center, numVoxels, voxelSpacing, dcos):
         """
         Calculates the LPS origin (toplc) from the center.
-        
+
         """
         origin = np.array([0.0, 0.0, 0.0])
 
@@ -956,13 +956,13 @@ class PfileMapper:
                 origin[i] -= dcos[j][i] * voxelSpacing[j] * (numVoxels[j] / 2.0 - 0.5)
         return origin
 
-    def read_data(self):            
+    def read_data(self):
         """
-        This method reads data from the pfile and puts the data into 
-        the CellData arrays. If elliptical k-space sampling was used, 
-        the data is zero-padded.  Other reduced k-space sampling 
+        This method reads data from the pfile and puts the data into
+        the CellData arrays. If elliptical k-space sampling was used,
+        the data is zero-padded.  Other reduced k-space sampling
         strategies aren't supported yet.
-        
+
         """
 
         numCoils        = self.get_num_coils
@@ -983,9 +983,9 @@ class PfileMapper:
 
         numBytesPerCoil += numDummyBytesPerCoil
 
-        #  Only read in one coil at a time to reduce memory footprint 
+        #  Only read in one coil at a time to reduce memory footprint
         specData_size = int(np.round((numBytesPerCoil / dataWordSize), 0))
-        specData = np.zeros([specData_size, ], float) 
+        specData = np.zeros([specData_size, ], float)
 
         try:
             readOffset = self.hdr.rhr_rdb_hdr_off_data
@@ -1004,24 +1004,24 @@ class PfileMapper:
 
         #  Preallocate data arrays. The API only permits dynamic assignment at end of CellData, so for
         #  swapped cases where we need to insert data out of order they need to be preallocated.
-        
+
         data = np.zeros([cols, rows, slices, numTimePts, numCoils, numSpecPts], np.complex64)
 
         #  Blank scan prepended to data blocks.
-        dummyOffset = numPtsPerSpectrum 
+        dummyOffset = numPtsPerSpectrum
 
         #  If Chop On, then reinitialize chopVal:
         chopVal = 1
         if self.is_chop_on:
-            chopVal = -1 
+            chopVal = -1
 
-        #  pFileOOffset is the offset of the current data set within the 
-        #  pFile (i.e. a global data offset).  #  a given coil. 
+        #  pFileOOffset is the offset of the current data set within the
+        #  pFile (i.e. a global data offset).  #  a given coil.
         pFileOffset = 0
 
         for coilNum in range(numCoils):
             #  Offset is the offset within the current block of loaded data (ie. within a given coil)
-            offset = 0 
+            offset = 0
 
             tempData = None
             if dataWordSize == 4:
@@ -1030,13 +1030,13 @@ class PfileMapper:
                 tempData = np.fromfile(filelike, dtype='i2', count=int(numBytesPerCoil / dataWordSize))
             if self.endian != 'little':
                 tempData.byteswap(True)     # swap in-place
-            specData = tempData.astype(np.float32)     
+            specData = tempData.astype(np.float32)
 
             for timePt in range(numTimePts):
 
                 #  Should a dummy scan be skipped over?
                 if self.add_dummy(pFileOffset, coilNum, timePt):
-                    offset      += dummyOffset 
+                    offset      += dummyOffset
                     pFileOffset += dummyOffset
 
                 for arrayNumber in range(arraysPerVolume):
@@ -1057,20 +1057,20 @@ class PfileMapper:
                         tempFloat = specData[offset:offset + numFreqPts * numComponents]
                         data[x, y, z, timePt, coilNum, :] = chopVal * tempFloat.view(np.complex64)
                     else:
-                        pass  # do nothing because array is initialized to zeros 
+                        pass  # do nothing because array is initialized to zeros
 
                     if wasSampled:
                         offset      += numPtsPerSpectrum
                         pFileOffset += numPtsPerSpectrum
 
-        filelike.close() 
+        filelike.close()
 
         self.raw_data = data
-        
+
         #  Modify the data loading behavior.  For single voxel multi-acq data
         #  this means return the averaged (suppresssed data, if applicable).
 
-        numUnsuppressed = self.get_number_unsuppressed_acquisitions 
+        numUnsuppressed = self.get_number_unsuppressed_acquisitions
         numSuppressed   = self.get_number_suppressed_acquisitions
 
         # bjs - changed numTimePoints to >= 1 below due to Pom's fidcsi 13C data
@@ -1078,9 +1078,9 @@ class PfileMapper:
 
         # Check if single voxel
         self.is_svs = False
-        if ((numVoxels[0] * numVoxels[1] * numVoxels[2] == 1) and (numTimePts >= 1) and (numSuppressed >= 1)): 
+        if ((numVoxels[0] * numVoxels[1] * numVoxels[2] == 1) and (numTimePts >= 1) and (numSuppressed >= 1)):
             self.is_svs = True
-        
+
         if self.is_svs:
             self.raw_unsuppressed = self.raw_data[:, :, :, 0:numUnsuppressed, :, :]
             self.raw_suppressed   = self.raw_data[:, :, :, numUnsuppressed:, :, :]
@@ -1100,12 +1100,12 @@ class PfileMapperProbeSL(PfileMapper):
     def __init__(self, file_name, hdr, version, endian):
         """
         Quick attempt to make sense of the probe-sl CSI data
-        
+
         """
         PfileMapper.__init__(self, file_name, hdr, version, endian)
 
     @property
-    def get_voxel_spacing(self):  
+    def get_voxel_spacing(self):
         """
         Get the voxel spacing in 3D. Note that the slice spacing may include
         a skip.
@@ -1118,8 +1118,8 @@ class PfileMapperProbeSL(PfileMapper):
         nvox = self.get_num_voxels
         voxspace[0] = fov[0] / nvox[0]
         voxspace[1] = fov[1] / nvox[1]
-        voxspace[2] = fov[2] / nvox[2]       
-    
+        voxspace[2] = fov[2] / nvox[2]
+
         return voxspace
 
 
@@ -1128,38 +1128,38 @@ class PfileMapperSlaser(PfileMapper):
     def __init__(self, file_name, hdr, version, endian):
         """
         This info was provided by Ralph Noeske at GE who wrote the sLASER
-        sequence in collaboration with Gulin Oz. Needed to get a few 
+        sequence in collaboration with Gulin Oz. Needed to get a few
         parameters from different header locations, but otherwise the basic
         code seems to work OK.
 
         rdb_hdr_user0 = rhuser0 = 6024 (sampling frequency)
         rdb_hdr_user4 = rhuser4 = 64 (number of averages)
         rdb_hdr_user19 = rhuser19 = 8 (number of reference frames)
-        
-        image_user8 = opuser8 is used as starting for voxel dimension and location (opuser8,9,10,11,12,13)
-        
-        The sub-echo-times are TE1 = 8ms and TE2 = 12ms (opuser20 and 21).  
 
-        
+        image_user8 = opuser8 is used as starting for voxel dimension and location (opuser8,9,10,11,12,13)
+
+        The sub-echo-times are TE1 = 8ms and TE2 = 12ms (opuser20 and 21).
+
+
         """
         PfileMapper.__init__(self, file_name, hdr, version, endian)
 
     @property
-    def get_number_unsuppressed_acquisitions(self):    
+    def get_number_unsuppressed_acquisitions(self):
         """
         For single voxel acquisitions, return the number of
-        unsuppressed acquisitions.        
-        
+        unsuppressed acquisitions.
+
         """
         user19 = self.hdr.rhr_rh_user19
         return int(user19)
 
     @property
-    def get_number_suppressed_acquisitions(self):    
+    def get_number_suppressed_acquisitions(self):
         """
         For single voxel acquisitions, return the number of
-        suppressed acquisitions.        
-        
+        suppressed acquisitions.
+
         """
         user4 = self.hdr.rhr_rh_user4
         return int(user4)
@@ -1231,20 +1231,20 @@ class PfileMapperGaba(PfileMapper):
         if self.endian != 'little':
             tempData.byteswap(True)     # swap in-place
 
-        tempData = tempData.astype(np.float32)    
+        tempData = tempData.astype(np.float32)
         tempData = tempData.view(np.complex64)
 
         if nechoes == 1:
             tempData = tempData.reshape((1, 1, 1, nreceivers, totalframes, npoints))
             self.raw_data = np.swapaxes(tempData, -1, -3)
-            
+
             if (dataframes + refframes) != nframes:
                 mult = 1
                 dataframes *= nex
                 refframes = nframes - dataframes
             else:
                 mult = 1.0 / nex
-            
+
             self.raw_unsuppressed = self.raw_data[:, :, :, :, 1:(refframes + 1), :]
             self.raw_suppressed   = self.raw_data[:, :, :, :, (refframes + 1):, :]
 
@@ -1259,13 +1259,13 @@ class PfileMapperGaba(PfileMapper):
                 mult = nex / 2
                 multw = 1
                 noadd = 0
-            
+
             if totalframes != (dataframes + refframes + 1) * nechoes:
                 raise ValueError('# of totalframes not same as (dataframes + refframes + 1) * nechoes')
 
             tempData = tempData.reshape((1, 1, 1, nreceivers, totalframes, npoints))
             self.raw_data = np.swapaxes(tempData, -1, -3)
-            
+
             # Marked as MM (180404) in GELoad.m
             X1, X2 = np.meshgrid(np.arange(refframes), np.arange(nechoes))
             X1 = X1.T.ravel()
@@ -1275,7 +1275,7 @@ class PfileMapperGaba(PfileMapper):
             Y2 = (1 + (totalframes / nechoes) * X2 + X1).astype(int)
 
             self.raw_unsuppressed = self.raw_data[:, :, :, :, Y2, :] * Y1 * multw
-            
+
             X1, X2 = np.meshgrid(np.arange(dataframes), np.arange(nechoes))
             X1 = X1.T.ravel()
             X2 = X2.T.ravel()
@@ -1288,14 +1288,14 @@ class PfileMapperGaba(PfileMapper):
             # Up to this point we have simply replicated the logic of the GELoad function.
             # Now reorganise dimensions to give a editing dimension.
             # This means that this is done in a not particularly clear order, but it enables testing against
-            # the matlab code. 
+            # the matlab code.
 
             reorg_suppressed = []
             reorg_unsuppressed = []
             for ne in range(nechoes):
                 reorg_suppressed.append(self.raw_suppressed[:, :, :, :, ne::nechoes, :])
                 reorg_unsuppressed.append(self.raw_unsuppressed[:, :, :, :, ne::nechoes, :])
-                
+
             reorg_suppressed = np.stack(reorg_suppressed, axis=-1)
             # Rearange axes to (x, y, z, t, coils, dynamics, edit)
             self.raw_suppressed = np.moveaxis(reorg_suppressed, (4, 5), (5, 4))
