@@ -28,11 +28,14 @@ from pathlib import Path
 import json
 
 from nibabel.nifti2 import Nifti2Image
-from spec2nii import nifti_mrs
 from spec2nii import __version__ as spec2nii_ver
 # There are case specific imports below
 
 
+class Spec2niiError(Exception):
+    pass
+
+
 class spec2nii:
     def __init__(self):
         cite_str = "Clarke WT, Bell TK, Emir UE, Mikkelsen M, Oeltzschner G, Shamaei A, Soher BJ, Wilson M. "\
@@ -117,6 +120,11 @@ class spec2nii:
             nargs='+',
             default=None,
             help="Specify the shape of higher (5th-7th) dimensions. Applies numpy style reshaping.")
+        parser_philips.add_argument(
+            "--special",
+            type=str,
+            default=None,
+            help="Identify special case sequence. Options: 'hyper'.")
         parser_philips = add_common_parameters(parser_philips)
         parser_philips.set_defaults(func=self.philips)
 
@@ -124,10 +132,15 @@ class spec2nii:
         parser_p_dl = subparsers.add_parser('philips_dl', help='Convert from Philips data/list format.')
         parser_p_dl.add_argument('data', help='.data file', type=Path)
         parser_p_dl.add_argument('list', help='.list file', type=Path)
-        parser_p_dl.add_argument('spar', help='.SPAR file', type=Path)
+        parser_p_dl.add_argument('aux', help='Auxiliary file: .SPAR or DICOM file', type=Path)
         # for idx in range(5, 8):
         #     parser_p_dl.add_argument(f"-d{idx}", f"--dim{idx}", type=str, help=f"Specify dim {idx} loop counter.")
         #     parser_p_dl.add_argument(f"-t{idx}", f"--tag{idx}", type=str, help=f"Specify dim {idx} NIfTI MRS tag.")
+        parser_p_dl.add_argument(
+            "--special",
+            type=str,
+            default=None,
+            help="Identify special case sequence. Options: 'hyper'.")
         parser_p_dl = add_common_parameters(parser_p_dl)
         parser_p_dl.set_defaults(func=self.philips_dl)
 
@@ -274,17 +287,12 @@ class spec2nii:
 
         self.outputDir = args.outdir
 
-        if args.nifti1:
-            nifti_mrs.NIfTI_MRS = nifti_mrs.get_mrs_class(nifti=1)
-        else:
-            nifti_mrs.NIfTI_MRS = nifti_mrs.get_mrs_class(nifti=2)
-
         args.func(args)
 
         if self.imageOut:
             self.implement_overrides(args)
             self.validate_output()
-            self.write_output(args.json)
+            self.write_output(args.json, args.nifti1)
             self.validate_write(args.verbose)
             if args.verbose:
                 print(f'Please cite {cite_str}.')
@@ -314,10 +322,20 @@ class spec2nii:
 
     def validate_output(self):
         """Run NIfTI MRS validation on output."""
+        import nifti_mrs.validator as validate
+        # Currently this repeats the validation before the save.
+        # But useful here to do exception handling
         for f_out, nifti_mrs_img in zip(self.fileoutNames, self.imageOut):
-            nifti_mrs_img.validate()
+            try:
+                validate.validate_nifti_mrs(nifti_mrs_img)
+            except (
+                    validate.headerExtensionError,
+                    validate.niftiDataError,
+                    validate.niftiHeaderError) as exc:
 
-    def write_output(self, write_json=False):
+                raise Spec2niiError(f'Generated file {f_out} failed validation.') from exc
+
+    def write_output(self, write_json=False, nifti1=False):
         """Write any NIfTI MRS objects stored.
         If write_json is true also write meta-data as sidecar.
         """
@@ -325,7 +343,20 @@ class spec2nii:
 
         for f_out, nifti_mrs_img in zip(self.fileoutNames, self.imageOut):
             out = self.outputDir / (f_out + '.nii.gz')
-            nifti_mrs_img.save(out)
+
+            if nifti1:
+                # If nifti1 is requested just remake the file.
+                # This is more than a bit hacky, but avoids passing the option to every end-point.
+                from nifti_mrs.create_nmrs import gen_nifti_mrs_hdr_ext
+                gen_nifti_mrs_hdr_ext(
+                    nifti_mrs_img[:],
+                    nifti_mrs_img.dwelltime,
+                    nifti_mrs_img.hdr_ext,
+                    nifti_mrs_img.getAffine('voxel', 'world'),
+                    nifti_version=1)\
+                    .save(out)
+            else:
+                nifti_mrs_img.save(out)
 
             if write_json:
                 out_json = self.outputDir / (f_out + '.json')
@@ -350,7 +381,7 @@ class spec2nii:
     def twix(self, args):
         """ Twix format handler."""
         from mapvbvd import mapVBVD
-        from spec2nii.twixfunctions import process_twix, examineTwix
+        from spec2nii.Siemens.twixfunctions import process_twix, examineTwix
 
         # Call mapvbvd to load the twix file.
         twixObj = mapVBVD(args.file, quiet=args.quiet)
@@ -380,7 +411,7 @@ class spec2nii:
     # (Siemens) DICOM (.ima) format
     def dicom(self, args):
         """Siemens DICOM format handler."""
-        from spec2nii.dicomfunctions import multi_file_dicom
+        from spec2nii.Siemens.dicomfunctions import multi_file_dicom
         path_in = Path(args.file)
         if path_in.is_dir():
             # Look for typical dicom file extensions
@@ -405,12 +436,18 @@ class spec2nii:
             from nibabel import save
             for img, f_out in zip(self.imageOut, self.fileoutNames):
                 out = self.outputDir / (f_out + '_voi.nii.gz')
-                save(Nifti2Image(np.ones((1, 1, 1), int), img.hdr_ext['VOI']), out)
+                mask_data = np.ones((1, 1, 1), int)
+                save(
+                    Nifti2Image(
+                        mask_data,
+                        img.hdr_ext['VOI'],
+                        dtype=mask_data.dtype),
+                    out)
 
     # Siemens RDA (.rda) format
     def rda(self, args):
         """Siemens RDA format handler."""
-        from spec2nii.rda import convert_rda
+        from spec2nii.Siemens.rda import convert_rda
         self.imageOut, self.fileoutNames = convert_rda(args.file, args.fileout, args.verbose)
 
     # (UIH) DICOM (.dcm) format
@@ -436,29 +473,27 @@ class spec2nii:
     # Philips SDAP/SPAR handler
     def philips(self, args):
         # philips specific imports
-        from spec2nii.philips import read_sdat_spar_pair
+        from spec2nii.Philips.philips import read_sdat_spar_pair
 
-        self.imageOut = read_sdat_spar_pair(args.sdat, args.spar, args.shape, args.tags)
-
-        # name of output
-        if args.fileout:
-            mainStr = args.fileout
-        else:
-            mainStr = args.sdat.stem
-
-        self.fileoutNames.append(mainStr)
+        self.imageOut, self.fileoutNames = read_sdat_spar_pair(
+            args.sdat,
+            args.spar,
+            args.shape,
+            args.tags,
+            args.fileout,
+            args.special)
 
     # Philips data/list (+SPAR) handler
     def philips_dl(self, args):
         # philips specific imports
-        from spec2nii.philips_data_list import read_data_list_pair
+        from spec2nii.Philips.philips_data_list import read_data_list_pair
 
         # TO DO
         # overrides = {'dims': (args.dim5, args.dim6, args.dim7),
         #              'tags': (args.tag5, args.tag6, args.tag7)}
 
         # self.imageOut, file_names = read_data_list_pair(args.data, args.list, args.spar, overrides)
-        self.imageOut, file_names = read_data_list_pair(args.data, args.list, args.spar)
+        self.imageOut, file_names = read_data_list_pair(args.data, args.list, args.aux, args.special)
 
         # name of output
         if args.fileout:
@@ -473,7 +508,7 @@ class spec2nii:
     def philips_dicom(self, args):
         """Philips DICOM format handler."""
         from warnings import warn
-        from spec2nii.philips_dcm import multi_file_dicom
+        from spec2nii.Philips.philips_dcm import multi_file_dicom
         warn('This Philips DICOM conversion routine is experimental and poorly tested.'
              ' Please get in contact with test data to help improve it.')
         path_in = Path(args.file)
@@ -515,6 +550,7 @@ class spec2nii:
     # Bruker 2dseq files with FG_COMPLEX
     def bruker(self, args):
         from spec2nii.bruker import read_bruker
+
         self.imageOut, self.fileoutNames = read_bruker(args)
 
     # Varian parser
